# assoc-scan

Associative scan package for DRYing some code between repos

# cite

```bibtex
@software{Kyrylov_Accelerated_Scan_2024,
    author = {Kyrylov, Volodymyr},
    doi = {10.5281/zenodo.10600962},
    month = jan,
    title = {{Accelerated Scan}},
    version = {0.1.2},
    year = {2024}
}
```
